"""
    我的客户页面 用例
"""

import pytest
from PageObjects.myClient_page import MyClientPage
from PageObjects.customersDetails_page import CustomersDetailsPage
import time


@pytest.mark.usefixtures("init")
class TestMyClient:

    # 跳转到 我的客户 页面
    def test_to_myClient(self, init):
        # 步骤
        MyClientPage(init).to_myClient()
        # 断言
        assert MyClientPage(init).is_myClient_exist()

    # 填写 客户信息 创建客户
    def test_newClient(self, init):
        MyClientPage(init).newClient()
        assert MyClientPage(init).is_newClient_success()

    # 点击 列表手机号文本
    def test_details_button(self, init):
        MyClientPage(init).click_mobile_text()
        assert CustomersDetailsPage(init).is_basicInfo_exist()
